# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-07-22 10:28
from __future__ import unicode_literals

from django.db import migrations, models

from feature_flipper import flipper_settings


class Migration(migrations.Migration):

    dependencies = [
        ('feature_flipper', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='featureflipper',
            name='feature',
            field=models.CharField(choices=flipper_settings.FEATURE_FLIPPER_FLAGS, max_length=200),
        ),
    ]



from django.contrib import admin
from django.db.models import ManyToManyField

from .models import get_feature_model


FeatureFlipper = get_feature_model()


def _is_m2m(user_field):
    field = FeatureFlipper._meta.get_field(user_field)
    return isinstance(field, ManyToManyField)


def get_horizontal_filter():
    """If the USER_FEATURE_FIELD is a M2M field, set it to filter_horizontal.
    """
    user_field = FeatureFlipper.USER_FEATURE_FIELD
    return (user_field, ) if _is_m2m(user_field) else ()


def get_flat_filter():
    """If USER_FEATURE_FIELD is _not_ M2M, just return the regular fields.
    """
    user_field = FeatureFlipper.USER_FEATURE_FIELD

    return ('feature', user_field) if not _is_m2m(user_field) else ('feature',)


class FeatureFlipperAdmin(admin.ModelAdmin):
    """Manage the Feature Flipper
    """
    filter_horizontal = get_horizontal_filter()

    list_display = 'feature', 'everyone'
    list_filter = get_flat_filter()
    list_editable = 'everyone',

    search_fields = 'feature',


admin.site.register(FeatureFlipper, FeatureFlipperAdmin)



from os import path
from setuptools import find_packages, setup

README_PATH = path.join(path.dirname(path.abspath(__file__)), 'README.md')

try:
    import m2r
    LONG_DESCRIPTION = m2r.parse_from_file(README_PATH)
except (ImportError, IOError, FileNotFoundError):
    # m2r not installed or file does not exist
    LONG_DESCRIPTION = ''

setup(
    name='django-feature-flipper',
    author='Pebble',
    author_email='scott.walton@mypebble.co.uk',
    description='A simple, customisable, feature flipper',
    url='https://github.com/mypebble/django-feature-flipper.git',
    version='0.1.1',
    packages=find_packages(),
    license='MIT',
    long_description=LONG_DESCRIPTION,
    install_requires=[
        'django',
    ]
)
